==> eiffelstudio-16.05.tar: F_code/C2/kl56.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl56.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F77_883 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F77_884 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F77_885 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F77_886 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F77_887 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F77_888 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F77_889 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F77_890 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F77_891 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(7, 0x00).id, 7, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F8_69(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F8_72(RTCW(loc1));
	}
	ti4_1 = F8_73(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_74(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_75(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_76(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_77(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_78(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F77_892 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(7, 0x00).id, 7, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F8_70(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F8_72(RTCW(loc1));
	}
	ti4_1 = F8_73(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_74(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_75(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_76(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_77(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F8_78(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.utc_clock */
EIF_REFERENCE F77_893 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {KL_SYSTEM_CLOCK}.local_clock */
EIF_REFERENCE F77_894 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit56 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/kl56.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl56.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F87_986 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F87_987 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F87_988 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F87_989 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F87_990 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F87_991 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F87_992 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F87_993 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F87_994 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(11, 0x01).id, 11, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F12_90(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F12_93(RTCW(loc1));
	}
	ti4_1 = F12_94(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_95(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_96(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_97(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_98(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_99(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_100(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F87_995 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(11, 0x01).id, 11, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F12_91(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F12_93(RTCW(loc1));
	}
	ti4_1 = F12_94(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_95(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_96(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_97(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_98(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_99(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F12_100(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

void EIF_Minit56 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
